
/**
 * Representation of a single sample of sensor values from the Finch.  In particular,
 * a sample contains:
 * <UL>
 * <LI>  The light levels (left and right channels)
 * <LI>  The acceleration levels (X, Y, and Z) in units of 'g'
 * <LI>  The obstacle values (boolean representing whether an obstacle is there or not)
 *     		for the left and right sensors
 * <LI>  The temperature level (in Celsius)
 * <LI>  The time (in milliseconds) that the sample was taken.
 * </UL>
 * <P>
 * 
 * @author Andrew H. Fagg and Steven Ness
 *
 */ 

public class FinchSensor implements Comparable<FinchSensor>
{
	/**
	 * Holds the array of light values
	 */
	private int light[];
	
	/**
	 * Holds the array of acceleration values
	 */
	private double acceleration[];
	
	/**
	 * Holds the array of obstacle values
	 */
	private boolean obstacle[];
	
	/**
	 * Holds the temperature value
	 */
	private double temperature;
	
	/**
	 * The time (in milliseconds) that the sample was taken. 
	 */
	private long sample_time;
	
	/**
	 * Primary constructor
	 * 
	 * @param light			2-element array of light levels
	 * @param acceleration	3-element array of acceleration values
	 * @param obstacle		2-element array of obstacle values
	 * @param temperature	Temperature
	 */
	public FinchSensor(int light[], double acceleration[], 
			boolean obstacle[], double temperature)
	{
		this.light = light;
		this.acceleration = acceleration;
		this.obstacle = obstacle;
		this.temperature = temperature;
		
		// Record the time of sample
		this.sample_time = System.currentTimeMillis();
	}
	
	/**
	 * Accessor to acceleration
	 * 
	 * @return	Array of acceleration values
	 */
	public double[] getAcceleration()
	{
		return(acceleration);
	}
	
	/**
	 * Accessor to temperature.
	 * 
	 * @return The temperature
	 */
	
	public double getTemperature()
	{
		return(temperature);
	}
	
	/**
	 * Light level accessor
	 * 
	 * @return The array of light levels
	 */
	
	public int[] getLight()
	{
		return(light);
	}
	
	/**
	 * Accessor to obstacle sensor 
	 * 
	 * @return The obstacle sensor array
	 */
	
	public boolean[] getObstacle()
	{
		return(obstacle);
	}
	
	/**
	 * Accessor to the sample time
	 * 
	 * @return The sample time
	 */
	
	public long getSampleTime()
	{
		return(sample_time);
	}
	
	/**
	 * Overriding the Object toString method
	 * 
	 * @return	A representation of this object as a String
	 */
	public String toString()
	{
		return(this.sample_time + " " +
				this.light[0] + " " +
				this.light[1] + " " +
				this.acceleration[0] + " " +
				this.acceleration[1] + " " +
				this.acceleration[2] + " " +
				this.obstacle[0] + " " +
				this.obstacle[1] + " " +
				this.temperature);
	}
	
	/**
	 * Compare this FinchSensor to obj using the "natural ordering" 
	 *   (by time that the sample was taken)
	 * 
	 * @param obj	FinchSensor object
	 * @return 1 if this was sampled after obj, 0 if sampled at the same time, 
	 * and -1 otherwise
	 *     
	 */
	public int compareTo(FinchSensor obj)
	{
		if(this.sample_time > obj.sample_time)
			return(1);
		else if(this.sample_time < obj.sample_time)
			return(-1);
		return(0);
	}
}